﻿# Author:            weixeflo@fawcs.info
# Date:              20160325
# Description:       Script discovers all triggerd alarms from a vcenter and returns discovery for zabbix:
# Usage:             

param (
  [Parameter(Mandatory=$true,Position=1)]
  [string]$vCenter="",
   [Parameter(Mandatory=$true,Position=2)]
  [string]$user="",
   [Parameter(Mandatory=$true,Position=3)]
  [string]$password=""
)



Add-PSSnapin VMWare.VimAutomation.Core
#VAR definitions
$unixtime=Get-Date -Date "01/01/1970"
$output=""


#functions
Function convertSeverity {
    param(
        [Parameter(Mandatory=$true)]
        [string]$severityString
    )
    $ret="0"
    switch ($severityString)
    {
        green { $ret="0"; break }
        grün { $ret="0"; break }
        yellow { $ret="1"; break }
        gelb { $ret="1"; break }
        red { $ret="2"; break }
        rot { $ret="2"; break }
        gray { $ret="3"; break }
        grau { $ret="3"; break }

    }

    return $ret
}

Function ReplaceMutations {

    param (
       [string]$Text 
    )
 
    # create Table with replace map
    $characterMap = @{}
    $characterMap.([Int][Char]'ä') = "ae"
    $characterMap.([Int][Char]'ö') = "oe"
    $characterMap.([Int][Char]'ü') = "ue"
    $characterMap.([Int][Char]'ß') = "ss"
    $characterMap.([Int][Char]'Ä') = "Ae"
    $characterMap.([Int][Char]'Ü') = "Ue"
    $characterMap.([Int][Char]'Ö') = "Oe"
    $characterMap.([Int][Char]'á') = "_"
    $characterMap.([Int][Char]"`n") = " "
    
    # Replace chars
    ForEach ($key in $characterMap.Keys) {
        $Text = $Text -creplace ([Char]$key),$characterMap[$key] 
    }
 
     # return result
     $Text
}





$connect=Connect-VIServer $vCenter -User $user -Password $password

$output='{ "data" : ['

Foreach ($alarm in (Get-Folder -NoRecursion).ExtensionData.TriggeredAlarmState) {
        $AlarmName = ReplaceMutations((Get-View $alarm.Alarm).Info.Name)
        $AlarmEntity = ReplaceMutations((Get-View $alarm.Entity).Name)
        $AlarmTime = $($alarm.Time)
        $AlarmSeverity = convertSeverity($($alarm.OverallStatus))
        $AlarmID = $($alarm.Key)
        $Timestamp=(New-TimeSpan -Start $unixtime -End $AlarmTime.DateTime ).TotalSeconds
        $AlarmACK=$($alarm.Acknowledged)


        #echo $AlarmName
        #echo $AlarmEntity
        #echo $AlarmTime
        #echo $AlarmSeverity
        #echo $AlarmID
        #echo $AlarmACK
        #echo $AlarmStatus
        #echo ""

        $output= $output + "{"
        $output= $output + "`"{#ALARMENTITY}`": `"$AlarmEntity`", "
        $output= $output + "`"{#ALARMNAME}`": `"$AlarmName`", "
        $output= $output + "`"{#ALARMTIME}`": `"$Timestamp`", "
        $output= $output + "`"{#ALARMSEVERITY}`": `"$AlarmSeverity`", "
        $output= $output + "`"{#ALARMACK}`": `"$AlarmACK`", "
        $output= $output + "`"{#ALARMID}`": `"$AlarmID`""
        $output= $output + "}, "


}
$output=$output.Substring(0,$output.Length-2) + " ] }"

if($output -eq "" )
{
    echo "ERROR: Output is not defined!"
} else {
    echo $output
}




